@@ -1,5 +1,7 @@
 import argparse
 
+from oireachtas_data import members
+
 from oireachtas_nlp import logger
 from oireachtas_nlp.models.para import ExtendedParas
 from oireachtas_nlp.utils import get_speaker_para_map, get_party_para_map
@@ -24,6 +26,10 @@ def main():
             if len(paras) < 10:
                 continue
 
+            member = members.get_member_from_name(speaker)
+            if member is None:
+                continue
+
             extended_paras = ExtendedParas(data=paras)
             if len(extended_paras.text_obj.content) < 50000:
                 continue
