@@ -6,7 +6,7 @@ from logging.handlers import RotatingFileHandler
 from oireachtas_nlp.constants import LOG_LOCATION
 
 
-FORMAT = '%(asctime)s|%(levelname)s| %(message)s'
+FORMAT = "%(asctime)s|%(levelname)s| %(message)s"
 
 
 class ColourfulFormatter(logging.Formatter):
@@ -18,14 +18,14 @@ class ColourfulFormatter(logging.Formatter):
     bold_red = "\x1b[31;1m"
     reset = "\x1b[0m"
     format = FORMAT
-    format_problematic = FORMAT + ' (%(filename)s:%(lineno)d)'
+    format_problematic = FORMAT + " (%(filename)s:%(lineno)d)"
 
     FORMATS = {
         logging.DEBUG: cyan + format + reset,
         logging.INFO: grey + format + reset,
         logging.WARNING: yellow + format_problematic + reset,
         logging.ERROR: red + format_problematic + reset,
-        logging.CRITICAL: bold_red + format_problematic + reset
+        logging.CRITICAL: bold_red + format_problematic + reset,
     }
 
     def format(self, record):
@@ -34,28 +34,18 @@ class ColourfulFormatter(logging.Formatter):
         return formatter.format(record)
 
 
-logger = logging.Logger('oireachtas_nlp', logging.DEBUG)
+logger = logging.Logger("oireachtas_nlp", logging.DEBUG)
 
-os.makedirs(
-    os.path.dirname(LOG_LOCATION),
-    exist_ok=True
-)
+os.makedirs(os.path.dirname(LOG_LOCATION), exist_ok=True)
 
-handler = RotatingFileHandler(
-    LOG_LOCATION,
-    maxBytes=1000000,
-    backupCount=20
-)
+handler = RotatingFileHandler(LOG_LOCATION, maxBytes=1000000, backupCount=20)
 handler.setFormatter(
     logging.Formatter(
-        fmt='%(asctime)s|%(levelname)s| %(message)s',
-        datefmt='%Y-%m-%d %H:%M:%S'
+        fmt="%(asctime)s|%(levelname)s| %(message)s", datefmt="%Y-%m-%d %H:%M:%S"
     )
 )
 logger.addHandler(handler)
 
 std_handler = logging.StreamHandler(sys.stdout)
-std_handler.setFormatter(
-    ColourfulFormatter()
-)
+std_handler.setFormatter(ColourfulFormatter())
 logger.addHandler(std_handler)
